Trait State Copy item path Source pub trait State: Sized {
type MembershipCoordinator ;
type Network ;
type Initializer ;
type UpgradeLock ;
type PublicKey ;
type PrivateKey ;
type StatePrivateKey ;
type StakeTableCapacity ;
type TimeoutDuration ;
type Storage ;
type GarbageCollectionInterval ;
}Expand description Builder’s type state specifies if members are set or not (unset).
You can use the associated types of this trait to control the state of individual members with the IsSet and IsUnset traits. You can change the state of the members with the Set* structs available in this module.
Type state of the member membership_coordinator.
It can implement either IsSet or IsUnset
Type state of the member network.
It can implement either IsSet or IsUnset
Type state of the member initializer.
It can implement either IsSet or IsUnset
Type state of the member upgrade_lock.
It can implement either IsSet or IsUnset
Type state of the member public_key.
It can implement either IsSet or IsUnset
Type state of the member private_key.
It can implement either IsSet or IsUnset
Type state of the member state_private_key.
It can implement either IsSet or IsUnset
Type state of the member stake_table_capacity.
It can implement either IsSet or IsUnset
Type state of the member timeout_duration.
It can implement either IsSet or IsUnset
Type state of the member storage.
It can implement either IsSet or IsUnset
Type state of the member garbage_collection_interval.
It can implement either IsSet or IsUnset
This trait is not dyn compatible .
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.